# TransferBoost (tboost)
Tooling for transfer learning with Boosting Models


## Installing tboost
Install `transferboost` directly from pip<br>
`pip install transferboost`

## Documentation
The documentation can be found [here](https://sbjelogr.github.io/TransferBoost).

## Supported models
`transferboost` supports the transfer learning for the following models:<br>
- XGBClassifier<br>
- LGBMClassifier<br>